summaryrefslogtreecommitdiffstats
path: root/telephony/java/com
diff options
context:
space:
mode:
authorSteven Liu <stevenliu@motorola.com>2014-07-10 14:10:50 -0500
committerVineeta Srivastava <vsrivastava@google.com>2014-09-05 22:13:11 +0000
commit9b656ee3201ee85e1bb3374ea2877aad4adab82b (patch)
tree4a87c4a528b4cc42f7db96990d6b99232f2c2075 /telephony/java/com
parent69dd40d08a164d5c357442733cf291719dfe94e8 (diff)
downloadframeworks_base-9b656ee3201ee85e1bb3374ea2877aad4adab82b.zip
frameworks_base-9b656ee3201ee85e1bb3374ea2877aad4adab82b.tar.gz
frameworks_base-9b656ee3201ee85e1bb3374ea2877aad4adab82b.tar.bz2
Plus code handling for non-NANP CDMA carrier
Since most of CDMA network do not support phone number with "+" for international dialing, current AOSP support the "+" handling for NANP CDMA network, this part add the support for non-NANP CDMA Network, convert "+" to right IDD(International Direct Dialing) code. And adding a new property for current IDD. Bug: 17210134 Change-Id: I369083169bb3504f8de9774b65f3993dd561c525
Diffstat (limited to 'telephony/java/com')
-rw-r--r--telephony/java/com/android/internal/telephony/TelephonyProperties.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/telephony/java/com/android/internal/telephony/TelephonyProperties.java b/telephony/java/com/android/internal/telephony/TelephonyProperties.java
index 5ec4247..34992b8 100644
--- a/telephony/java/com/android/internal/telephony/TelephonyProperties.java
+++ b/telephony/java/com/android/internal/telephony/TelephonyProperties.java
@@ -123,8 +123,8 @@ public interface TelephonyProperties
/** Indicate the timer value for exiting emergency callback mode */
static final String PROPERTY_ECM_EXIT_TIMER = "ro.cdma.ecmexittimer";
- /** The international dialing prefix conversion string */
- static final String PROPERTY_IDP_STRING = "ro.cdma.idpstring";
+ /** the international dialing prefix of current operator network */
+ static final String PROPERTY_OPERATOR_IDP_STRING = "telephony.operator.idpstring";
/**
* Defines the schema for the carrier specified OTASP number